package com.jz.common.interceptor;

import java.util.ArrayList;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.core.GrantedAuthority;
import org.springframework.security.core.userdetails.UserDetails;
import org.springframework.security.core.userdetails.UserDetailsService;
import org.springframework.security.core.userdetails.UsernameNotFoundException;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import com.alibaba.fastjson.JSONObject;
import com.jz.dmp.modules.model.DmpMember;
import com.jz.dmp.modules.model.DmpPermission;
import com.jz.dmp.modules.model.DmpRole;
import com.jz.dmp.modules.service.sys.DmpMemberService;
import com.jz.dmp.modules.service.sys.DmpPermissionService;
import com.jz.dmp.modules.service.sys.DmpRoleService;

@Service
public class CustomUserService implements UserDetailsService {
	
	//@Autowired
	//DmpMemberprojectrole projectMemberRoleDao;
	@Autowired
	DmpMemberService dmpMemberService;
	
	@Autowired
	DmpRoleService dmpRoleService;
	
	@Autowired
	DmpPermissionService dmpPermissionService;
	
	/**
	 *
	 */
	@Override
	public UserDetails loadUserByUsername(String userName) {
		DmpMember user = null;
		try {
			user = dmpMemberService.findByUserName(userName);
		} catch (Exception e) {
			e.printStackTrace();
		}
		if (user != null) {
			//设置登录用户默认项目
			Integer defaultProjectId = dmpMemberService.getDefProjectByUserName(user.getUsername());
			user.setCurrentProjectId(defaultProjectId);
			//设置UserRole
			List<DmpRole> memberRoles = dmpRoleService.findMemberRolesByUserId(user.getUserId());
			user.setMemberRoleList(memberRoles);
			//设置当前默认项目用户所拥有的角色
			List<DmpRole> memberProjectRoles = dmpRoleService.findMemberProjRolesByUser(user);
			user.setMemberProjectRoleList(memberProjectRoles);
			//设置用户的资源
			List<DmpPermission> memberPermissions = dmpPermissionService.findPermissionByRoles(memberRoles);
			user.setMemberPermissionList(memberPermissions);
			//设置用户在当前默认项目的资源
			List<DmpPermission> memberProjPermissions = dmpPermissionService.findPermissionByRoles(memberProjectRoles);
			user.setMemberProjectPermissionList(memberProjPermissions);
			//设置用户资源
			List<DmpPermission> permissions = new ArrayList<DmpPermission>();
			if (!CollectionUtils.isEmpty(memberPermissions)) {
				String jsonStr = JSONObject.toJSONString(memberPermissions);
				List<DmpPermission> list = JSONObject.parseArray(jsonStr, DmpPermission.class);
				permissions.addAll(list);
			}
			if (!CollectionUtils.isEmpty(memberProjPermissions)) {
				String jsonStr = JSONObject.toJSONString(memberProjPermissions);
				List<DmpPermission> list = JSONObject.parseArray(jsonStr, DmpPermission.class);
				permissions.addAll(list);
			}
			user.setPermissionList(permissions);
			
			List<GrantedAuthority> grantedAuthorities = new ArrayList<>();
			//List<DmpPermission> permissions = permissionDao.getDmpDefaultPermission();
			/*
			 * DmpProjectMemberRole pmr = new DmpProjectMemberRole();
			 * pmr.setMemberId(userName); List<DmpProjectMemberRole> mrs =
			 * projectMemberRoleDao.getMemberProjectRole(pmr); for (DmpProjectMemberRole mr
			 * : mrs) { if (mr != null) { GrantedAuthority grantedAuthority = new
			 * CustomGrantedAuthority( mr.getProjectId().intValue(), mr.getRoleId());
			 * grantedAuthorities.add(grantedAuthority); } }
			 * user.setGrantedAuthorities(grantedAuthorities);
			 */
			
			return user;
		} else {
			throw new UsernameNotFoundException("用户: " + userName + " 不存在!");
		}
	}
}