package com.jz.dmp.modules.controller.projconfig;

import javax.servlet.http.HttpServletRequest;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.jz.common.annotation.MethodCallLogPrint;
import com.jz.common.bean.BaseBeanResponse;
import com.jz.common.constant.StatuConstant;
import com.jz.dmp.modules.controller.projconfig.bean.DmpProjectConfigInfoDto;
import com.jz.dmp.modules.controller.projconfig.bean.DmpProjectConfigInfoRequest;
import com.jz.dmp.modules.model.DmpProjectConfigInfo;
import com.jz.dmp.modules.service.projconfig.DmpProjectConfigInfoService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;

/**
 * 项目配置表Controller
 * @author ybz
 *
 */
@RestController
@RequestMapping("/dmp/project/config/info")
@Api(tags = "项目配置表")
public class DmpProjectConfigInfoController {
	
	@Autowired
	private DmpProjectConfigInfoService dmpProjectConfigInfoService;
	
	/**列表查询项目配置表
	 * @param dmpProjectConfigInfoRequest
	 * @return
	 */
	//@MethodCallLogPrint
	//@RequestMapping(method = RequestMethod.POST, value = "/findList")
	//@ApiOperation(value = "列表查询项目配置表", notes = "列表查询项目配置表")
	public BaseBeanResponse<DmpProjectConfigInfoDto> findList(@RequestBody DmpProjectConfigInfoRequest dmpProjectConfigInfoRequest, HttpServletRequest httpRequest){
		BaseBeanResponse<DmpProjectConfigInfoDto> baseBeanResponse = new BaseBeanResponse<DmpProjectConfigInfoDto>();
		try {
			baseBeanResponse = dmpProjectConfigInfoService.findList(dmpProjectConfigInfoRequest, httpRequest);
		} catch (Exception e) {
			baseBeanResponse.setMessage("查询失败");
			baseBeanResponse.setCode(StatuConstant.FAILURE_CODE);
			e.printStackTrace();
		}
		
		return baseBeanResponse;
	}
	
	/**获取项目配置信息
	 * @param dmpProjectConfigInfoRequest
	 * @return
	 */
	@MethodCallLogPrint
	@RequestMapping(method = RequestMethod.GET, value = "/view")
	@ApiOperation(value = "获取项目配置信息", notes = "获取项目配置信息")
	@ApiImplicitParam(name = "projectId", value = "项目主键")
	public BaseBeanResponse<DmpProjectConfigInfoDto> view(@RequestParam(name = "projectId", required = true ) Integer projectId, HttpServletRequest httpRequest){
		BaseBeanResponse<DmpProjectConfigInfoDto> baseBeanResponse = new BaseBeanResponse<DmpProjectConfigInfoDto>();
		try {
			baseBeanResponse = dmpProjectConfigInfoService.findByProjectId(projectId, httpRequest);
		} catch (Exception e) {
			baseBeanResponse.setMessage("请求失败");
			baseBeanResponse.setCode(StatuConstant.FAILURE_CODE);
			e.printStackTrace();
		}
		
		return baseBeanResponse;
	}
	
	/**新增或修改项目配置表
	 * @param dmpProjectConfigInfoRequest
	 * @return
	 */
	@MethodCallLogPrint
	@RequestMapping(method = RequestMethod.POST, value = "/addOrEdit")
	@ApiOperation(value = "新增或修改项目配置表", notes = "新增或修改项目配置表")
	public BaseBeanResponse<DmpProjectConfigInfo> addOrEdit(@RequestBody DmpProjectConfigInfo dmpProjectConfigInfo, HttpServletRequest httpRequest){
		BaseBeanResponse<DmpProjectConfigInfo> baseBeanResponse = new BaseBeanResponse<DmpProjectConfigInfo>();
		try {
			baseBeanResponse = dmpProjectConfigInfoService.addOrEdit(dmpProjectConfigInfo, httpRequest);
		} catch (Exception e) {
			baseBeanResponse.setMessage("新增或修改失败");
			baseBeanResponse.setCode(StatuConstant.FAILURE_CODE);
			e.printStackTrace();
		}
		
		return baseBeanResponse;
	}
	
}
